@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::C;
-$Time::C::VERSION = '0.007';
+$Time::C::VERSION = '0.008';
 # ABSTRACT: Convenient time manipulation.
 
 use overload (
@@ -13,6 +13,7 @@ use overload (
 use Carp qw/ croak /;
 use Function::Parameters qw/ :strict /;
 use Time::C::Sentinel;
+use Time::D;
 use Time::Moment;
 use Time::Piece ();
 use Time::Zone::Olson;
@@ -415,51 +416,15 @@ method second ($t: $new_second = undef) :lvalue {
 }
 
 
-method millisecond ($t: $new_msec = undef) :lvalue {
-    my $tm = $t->tm();
 
-    my $setter = sub {
-        my $ret = ($t->tm = $tm->plus_milliseconds($_[0] - $tm->millisecond))->millisecond;
-
-        return $t if defined $new_msec;
-        return $ret;
-    };
-
-    return $setter->($new_msec) if defined $new_msec;
-
-    sentinel value => $tm->millisecond, set => $setter;
-}
-
-
-method microsecond ($t: $new_msec = undef) :lvalue {
-    my $tm = $t->tm();
-
-    my $setter = sub {
-        my $ret = ($t->tm = $tm->plus_microseconds($_[0] - $tm->microsecond))->microsecond;
-
-        return $t if defined $new_msec;
-        return $ret;
-    };
-
-    return $setter->($new_msec) if defined $new_msec;
-
-    sentinel value => $tm->microsecond, set => $setter;
-}
-
-
-method nanosecond ($t: $new_nsec = undef) :lvalue {
-    my $tm = $t->tm();
-
-    my $setter = sub {
-        my $ret = ($t->tm = $tm->plus_nanoseconds($_[0] - $tm->nanosecond))->nanosecond;
-
-        return $t if defined $new_nsec;
-        return $ret;
-    };
-
-    return $setter->($new_nsec) if defined $new_nsec;
-
-    sentinel value => $tm->nanosecond, set => $setter;
+method diff ($t: $t2) {
+    my $epoch =
+      ref $t2 ?
+        $t2->can('epoch') ?
+          $t2->epoch :
+          croak "Object with no ->epoch method passed (". ref $t2 .")." :
+        $t2;
+    return Time::D->new($t->epoch, $epoch);
 }
 
 1;
@@ -476,7 +441,7 @@ Time::C - Convenient time manipulation.
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -876,54 +841,14 @@ If the form C<< $t->second($new_second) >> is used, it likewise sets the current
 
 The second is 0-based where second 0 is the first second of the minute. Legal values are in the range 0-59.
 
-=head2 millisecond
+=head1 METHODS
 
-  my $msec = $t->millisecond;
-  $t->millisecond = $msec;
-  $t->millisecond += 1000;
-  $t->millisecond++;
-  $t->millisecond--;
+=head2 diff
 
-  $t = $t->millisecond($new_msec);
+  my $d = $t1->diff($t2);
+  my $d = $t1->diff($epoch);
 
-Returns or sets the current millisecond of the second, updating the epoch accordingly.
-
-If the form C<< $t->millisecond($new_msec) >> is used, it likewise updates the current millisecond but returns the entire object.
-
-The millisecond is 0-based where millisecond 0 means exact to the second. Legal values are in the range 0-999.
-
-=head2 microsecond
-
-  use utf8;
-  my $µsec = $t->microsecond;
-  $t->microsecond = $µsec;
-  $t->microsecond += 1_000_000;
-  $t->microsecond++;
-  $t->microsecond--;
-
-  $t = $t->microsecond($new_µsec);
-
-Returns or sets the current microsecond of the second, updating the epoch accordingly.
-
-If the form C<< $t->microsecond($new_µsec) >> is used, it likewise updates the current microsecond but returns the entire object.
-
-The microsecond is 0-based where microsecond 0 means exact to the second. Legal values are in the range 0-999'999.
-
-=head2 nanosecond
-
-  my $nsec = $t->nanosecond;
-  $t->nanosecond = $nsec;
-  $t->nanosecond += 1_000_000_000;
-  $t->nanosecond++;
-  $t->nanosecond--;
-
-  $t = $t->nanosecond($new_nsec);
-
-Returns or sets the current nanosecond of the second, updating the epoch accordingly.
-
-If the form C<< $t->nanosecond($new_nsec) >> is used, it likewise updates the current nanosecond but returns the entire object.
-
-The nanosecond is 0-based where nanosecond 0 means exact to the second. Legal values are in the range 0-999'999'999.
+Creates a L<Time::D> object from C<$t1> and C<$t2> or C<$epoch>. It accepts either an arbitrary object that has an C<< ->epoch >> accessor returning an epoch, or a straight epoch.
 
 =head1 SEE ALSO
 
