@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::D;
-$Time::D::VERSION = '0.007';
+$Time::D::VERSION = '0.008';
 # ABSTRACT: Differentiate between two times
 
 use overload (
@@ -243,7 +243,7 @@ Time::D - Differentiate between two times
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -335,7 +335,7 @@ If the form C<< $d->comp($new_comp) >> is used, it likewise changes the comp epo
 
   $d = $d->sign($new_sign);
 
-Returns or sets the sign - whether the difference between C<< $d->base >> and C<< $d->comp >> is positive or negative, changing C<< $d->comp >> to either be before the base or after the base. The sign can be either C<+> or C<->.
+Returns or sets the sign part of the difference - whether the difference between C<< $d->base >> and C<< $d->comp >> is positive or negative. Changing it changes C<< $d->comp >> to either be before the base or after the C<< $d->base >>. The sign can be either C<+> or C<->.
 
 If the form C<< $d->sign($new_sign) >> is used, it likewise changes the sign but returns the entire object.
 
@@ -349,9 +349,9 @@ If the form C<< $d->sign($new_sign) >> is used, it likewise changes the sign but
 
   $d = $d->years($new_years);
 
-Returns or sets the difference in years between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
+Returns or sets the year part of the difference between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
 
-If the form C<< $d->years($new_years) >> is used, it likewise changes the difference in years but returns the entire object.
+If the form C<< $d->years($new_years) >> is used, it likewise changes the year part of the difference but returns the entire object.
 
 =head2 months
 
@@ -363,9 +363,9 @@ If the form C<< $d->years($new_years) >> is used, it likewise changes the differ
 
   $d = $d->months($new_months);
 
-Returns or sets the difference in months between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
+Returns or sets the month part of the difference between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
 
-If the form C<< $d->months($new_months) >> is used, it likewise changes the difference in months but returns the entire object.
+If the form C<< $d->months($new_months) >> is used, it likewise changes the month part of the difference but returns the entire object.
 
 =head2 weeks
 
@@ -377,9 +377,9 @@ If the form C<< $d->months($new_months) >> is used, it likewise changes the diff
 
   $d = $d->weeks($new_weeks);
 
-Returns or sets the difference in weeks between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
+Returns or sets the week part of the difference between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
 
-If the form C<< $d->weeks($new_weeks) >> is used, it likewise changes the difference in weeks but returns the entire object.
+If the form C<< $d->weeks($new_weeks) >> is used, it likewise changes the week part of the difference but returns the entire object.
 
 =head2 days
 
@@ -391,9 +391,9 @@ If the form C<< $d->weeks($new_weeks) >> is used, it likewise changes the differ
 
   $d = $d->days($new_days);
 
-Returns or sets the difference in days between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
+Returns or sets the day part of the difference between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
 
-If the form C<< $d->days($new_days) >> is used, it likewise changes the difference in days but returns the entire object.
+If the form C<< $d->days($new_days) >> is used, it likewise changes the day part of the difference but returns the entire object.
 
 =head2 hours
 
@@ -405,9 +405,9 @@ If the form C<< $d->days($new_days) >> is used, it likewise changes the differen
 
   $d = $d->hours($new_hours);
 
-Returns or sets the difference in hours between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
+Returns or sets the hour part of the difference between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
 
-If the form C<< $d->hours($new_hours) >> is used, it likewise changes the difference in hours but returns the entire object.
+If the form C<< $d->hours($new_hours) >> is used, it likewise changes the hour part of the difference but returns the entire object.
 
 =head2 minutes
 
@@ -419,9 +419,9 @@ If the form C<< $d->hours($new_hours) >> is used, it likewise changes the differ
 
   $d = $d->minutes($new_minutes);
 
-Returns or sets the difference in minutes between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
+Returns or sets the minute part of the difference between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
 
-If the form C<< $d->minutes($new_minutes) >> is used, it likewise changes the difference in minutes but returns the entire object.
+If the form C<< $d->minutes($new_minutes) >> is used, it likewise changes the minute part of the difference but returns the entire object.
 
 =head2 seconds
 
@@ -433,9 +433,9 @@ If the form C<< $d->minutes($new_minutes) >> is used, it likewise changes the di
 
   $d = $d->seconds($new_seconds);
 
-Returns or sets the difference in seconds between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
+Returns or sets the second part of the difference between the C<< $d->base >> and the C<< $d->comp >>. If changed, it changes C<< $d->comp >>.
 
-If the form C<< $d->seconds($new_seconds) >> is used, it likewise changes the difference in seconds but returns the entire object.
+If the form C<< $d->seconds($new_seconds) >> is used, it likewise changes the second part of the difference but returns the entire object.
 
 =head1 METHODS
 
@@ -443,7 +443,7 @@ If the form C<< $d->seconds($new_seconds) >> is used, it likewise changes the di
 
   my ($sign, $years, $months, $weeks, $days, $hours, $minutes, $seconds) = $d->to_array();
 
-Returns the difference between C<< $d->base >> and C<< $d->comp >> in the different units. This is different from accessing them via the accessors, because the accessors return the total difference in the specific unit you're asking for, while C<to_array> returns the units with previous units accounted for.
+Returns the difference between C<< $d->base >> and C<< $d->comp >> in the different units. This is like accessing them via the accessors, except you get everything in one single call. This method is what's used internally by the accessors to get their values.
 
 =over
 
